# geoca

[![image](https://img.shields.io/pypi/v/geoca.svg)](https://pypi.python.org/pypi/geoca)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

[English](README.md) 简体中文

**基于地理栅格数据的 CA 模型 Python 模块**

- 开源许可证：MIT License
- 文档网站：[https://Haorui-Jiang.github.io/geoca](https://Haorui-Jiang.github.io/geoca)

## 主要功能

- 从文件中读取栅格数据，并将数据转换成 Python 列表等格式。
- 根据输入的栅格数据创建栅格模板，并将数据统一替换到该栅格模板的对应位置。
- 根据栅格数据运行 CA 模型，分析人口或其他资源的迁移情况。

## 文件模板

- [cookiecutter-pypackage](https://github.com/opengeos/cookiecutter-pypackage): 使用 mkdocs 创建 Python 包的 Cookiecutter 模板。

## 致谢

在此，我要对田纳西大学的 [吴秋生博士](https://github.com/giswqs) 表示诚挚的感谢。吴博士在 [YouTube](https://youtube.com/playlist?list=PLAxJ4-o7ZoPcD-6wZ2xY5bXuu48Scu8kq&si=dq_x-xUJZvoflVqy) 上发布的精彩教学内容极大地丰富了我的 Python 知识。正是在他发布的教学课程视频的帮助下，我才得以逐步开发出 geoca 这个 Python 模块。衷心祝愿吴博士身体健康，工作顺利！
